@@ -1,25 +1,12 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
-Copyright 2017  Marco Martin <mart@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2017 Marco Martin <mart@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
-#include <QtTest>
+#include <QSignalSpy>
+#include <QTest>
 // KWin
 #include "../../src/client/compositor.h"
 #include "../../src/client/connection_thread.h"
@@ -28,8 +15,8 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "../../src/client/registry.h"
 #include "../../src/client/surface.h"
 #include "../../src/client/xdgforeign.h"
-#include "../../src/server/display.h"
 #include "../../src/server/compositor_interface.h"
+#include "../../src/server/display.h"
 #include "../../src/server/surface_interface.h"
 #include "../../src/server/xdgforeign_interface.h"
 
@@ -100,7 +87,7 @@ void TestForeign::init()
     m_display->start();
     QVERIFY(m_display->isRunning());
 
-    qRegisterMetaType<KWayland::Server::SurfaceInterface*>("KWayland::Server::SurfaceInterface");
+    qRegisterMetaType<KWayland::Server::SurfaceInterface *>("KWayland::Server::SurfaceInterface");
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
@@ -142,14 +129,16 @@ void TestForeign::init()
     QVERIFY(m_compositorInterface->isValid());
 
     QVERIFY(compositorSpy.wait());
-    m_compositor = registry.createCompositor(compositorSpy.first().first().value<quint32>(), compositorSpy.first().last().value<quint32>(), this);
+    const auto name = compositorSpy.first().first().value<quint32>();
+    const auto version = compositorSpy.first().last().value<quint32>();
+    m_compositor = registry.createCompositor(name, version, this);
 
     m_foreignInterface = m_display->createXdgForeignInterface(m_display);
     m_foreignInterface->create();
     QVERIFY(m_foreignInterface->isValid());
-    
+
     QVERIFY(exporterSpy.wait());
-    //Both importer and exporter should have been triggered by now
+    // Both importer and exporter should have been triggered by now
     QCOMPARE(exporterSpy.count(), 1);
     QCOMPARE(importerSpy.count(), 1);
 
@@ -159,17 +148,15 @@ void TestForeign::init()
 
 void TestForeign::cleanup()
 {
-#define CLEANUP(variable) \
-    if (variable) { \
-        delete variable; \
-        variable = nullptr; \
+#define CLEANUP(variable)                                                                                                                                      \
+    if (variable) {                                                                                                                                            \
+        delete variable;                                                                                                                                       \
+        variable = nullptr;                                                                                                                                    \
     }
 
     CLEANUP(m_exportedSurfaceInterface)
     CLEANUP(m_childSurfaceInterface)
 
-
-
     CLEANUP(m_compositor)
     CLEANUP(m_exporter)
     CLEANUP(m_importer)
@@ -187,8 +174,8 @@ void TestForeign::cleanup()
     CLEANUP(m_compositorInterface)
     CLEANUP(m_foreignInterface)
 
-    //internally there are some deleteLaters on exported interfaces
-    //we want them processed before we delete the connection
+    // internally there are some deleteLaters on exported interfaces
+    // we want them processed before we delete the connection
     if (m_display) {
         QSignalSpy destroyedSpy(m_display, &QObject::destroyed);
         m_display->deleteLater();
@@ -201,15 +188,15 @@ void TestForeign::cleanup()
 
 void TestForeign::doExport()
 {
-    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface*)));
+    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface *)));
     QVERIFY(serverSurfaceCreated.isValid());
 
     m_exportedSurface = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
 
-    m_exportedSurfaceInterface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface*>();
+    m_exportedSurfaceInterface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface *>();
 
-    //Export a window
+    // Export a window
     m_exported = m_exporter->exportTopLevel(m_exportedSurface, m_connection);
     QVERIFY(m_exported->handle().isEmpty());
     QSignalSpy doneSpy(m_exported.data(), &XdgExported::done);
@@ -219,15 +206,15 @@ void TestForeign::doExport()
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
     QVERIFY(transientSpy.isValid());
 
-    //Import the just exported window
+    // Import the just exported window
     m_imported = m_importer->importTopLevel(m_exported->handle(), m_connection);
     QVERIFY(m_imported->isValid());
 
-    QSignalSpy childSurfaceInterfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface*)));
+    QSignalSpy childSurfaceInterfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface *)));
     QVERIFY(serverSurfaceCreated.isValid());
     m_childSurface = m_compositor->createSurface();
     QVERIFY(childSurfaceInterfaceCreated.wait());
-    m_childSurfaceInterface = childSurfaceInterfaceCreated.first().first().value<KWayland::Server::SurfaceInterface*>();
+    m_childSurfaceInterface = childSurfaceInterfaceCreated.first().first().value<KWayland::Server::SurfaceInterface *>();
     m_childSurface->commit(Surface::CommitFlag::None);
 
     m_imported->setParentOf(m_childSurface);
@@ -236,7 +223,7 @@ void TestForeign::doExport()
     QCOMPARE(transientSpy.first().first().value<KWayland::Server::SurfaceInterface *>(), m_childSurfaceInterface.data());
     QCOMPARE(transientSpy.first().at(1).value<KWayland::Server::SurfaceInterface *>(), m_exportedSurfaceInterface.data());
 
-    //transientFor api
+    // transientFor api
     QCOMPARE(m_foreignInterface->transientFor(m_childSurfaceInterface), m_exportedSurfaceInterface.data());
 }
 
@@ -250,7 +237,7 @@ void TestForeign::testDeleteImported()
     doExport();
 
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
- 
+
     QVERIFY(transientSpy.isValid());
     m_imported->deleteLater();
     m_imported = nullptr;
@@ -267,18 +254,18 @@ void TestForeign::testDeleteChildSurface()
     doExport();
 
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
- 
+
     QVERIFY(transientSpy.isValid());
     m_childSurface->deleteLater();
 
     QVERIFY(transientSpy.wait());
 
-    //when the client surface dies, the server one will eventually die too
+    // when the client surface dies, the server one will eventually die too
     QSignalSpy surfaceDestroyedSpy(m_childSurfaceInterface, SIGNAL(destroyed()));
     QVERIFY(surfaceDestroyedSpy.wait());
 
     QVERIFY(!transientSpy.first().at(0).value<KWayland::Server::SurfaceInterface *>());
-    QCOMPARE(transientSpy.first().at(1).value<KWayland::Server::SurfaceInterface *>(), m_exportedSurfaceInterface.data());    
+    QCOMPARE(transientSpy.first().at(1).value<KWayland::Server::SurfaceInterface *>(), m_exportedSurfaceInterface.data());
 }
 
 void TestForeign::testDeleteParentSurface()
@@ -286,7 +273,7 @@ void TestForeign::testDeleteParentSurface()
     doExport();
 
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
- 
+
     QVERIFY(transientSpy.isValid());
     m_exportedSurface->deleteLater();
 
@@ -307,7 +294,7 @@ void TestForeign::testDeleteExported()
 
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
     QSignalSpy destroyedSpy(m_imported.data(), &KWayland::Client::XdgImported::importedDestroyed);
- 
+
     QVERIFY(transientSpy.isValid());
     m_exported->deleteLater();
     m_exported = nullptr;
@@ -326,7 +313,7 @@ void TestForeign::testExportTwoTimes()
 {
     doExport();
 
-    //Export second window
+    // Export second window
     KWayland::Client::XdgExported *exported2 = m_exporter->exportTopLevel(m_exportedSurface, m_connection);
     QVERIFY(exported2->handle().isEmpty());
     QSignalSpy doneSpy(exported2, &XdgExported::done);
@@ -336,29 +323,29 @@ void TestForeign::testExportTwoTimes()
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
     QVERIFY(transientSpy.isValid());
 
-    //Import the just exported window
+    // Import the just exported window
     KWayland::Client::XdgImported *imported2 = m_importer->importTopLevel(exported2->handle(), m_connection);
     QVERIFY(imported2->isValid());
 
-    //create a second child surface
-    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface*)));
+    // create a second child surface
+    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface *)));
     QVERIFY(serverSurfaceCreated.isValid());
 
     KWayland::Client::Surface *childSurface2 = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
 
-    KWayland::Server::SurfaceInterface *childSurface2Interface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface*>();
+    KWayland::Server::SurfaceInterface *childSurface2Interface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface *>();
 
     imported2->setParentOf(childSurface2);
     QVERIFY(transientSpy.wait());
-    
+
     QCOMPARE(transientSpy.first().first().value<KWayland::Server::SurfaceInterface *>(), childSurface2Interface);
     QCOMPARE(transientSpy.first().at(1).value<KWayland::Server::SurfaceInterface *>(), m_exportedSurfaceInterface.data());
 
-    //transientFor api
-    //check the old relationship is still here
+    // transientFor api
+    // check the old relationship is still here
     QCOMPARE(m_foreignInterface->transientFor(m_childSurfaceInterface), m_exportedSurfaceInterface.data());
-    //check the new relationship
+    // check the new relationship
     QCOMPARE(m_foreignInterface->transientFor(childSurface2Interface), m_exportedSurfaceInterface.data());
 }
 
@@ -369,29 +356,29 @@ void TestForeign::testImportTwoTimes()
     QSignalSpy transientSpy(m_foreignInterface, &KWayland::Server::XdgForeignInterface::transientChanged);
     QVERIFY(transientSpy.isValid());
 
-    //Import another time the exported window
+    // Import another time the exported window
     KWayland::Client::XdgImported *imported2 = m_importer->importTopLevel(m_exported->handle(), m_connection);
     QVERIFY(imported2->isValid());
 
-    //create a second child surface
-    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface*)));
+    // create a second child surface
+    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface *)));
     QVERIFY(serverSurfaceCreated.isValid());
 
     KWayland::Client::Surface *childSurface2 = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
 
-    KWayland::Server::SurfaceInterface *childSurface2Interface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface*>();
+    KWayland::Server::SurfaceInterface *childSurface2Interface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface *>();
 
     imported2->setParentOf(childSurface2);
     QVERIFY(transientSpy.wait());
-    
+
     QCOMPARE(transientSpy.first().first().value<KWayland::Server::SurfaceInterface *>(), childSurface2Interface);
     QCOMPARE(transientSpy.first().at(1).value<KWayland::Server::SurfaceInterface *>(), m_exportedSurfaceInterface.data());
 
-    //transientFor api
-    //check the old relationship is still here
+    // transientFor api
+    // check the old relationship is still here
     QCOMPARE(m_foreignInterface->transientFor(m_childSurfaceInterface), m_exportedSurfaceInterface.data());
-    //check the new relationship
+    // check the new relationship
     QCOMPARE(m_foreignInterface->transientFor(childSurface2Interface), m_exportedSurfaceInterface.data());
 }
 
