@@ -1,32 +1,16 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "surface.h"
-#include "buffer.h"
-#include "region.h"
 #include "output.h"
+#include "region.h"
 #include "wayland_pointer_p.h"
 
 #include <QGuiApplication>
 #include <QRegion>
 #include <QVector>
-#include <QWindow>
 #include <qpa/qplatformnativeinterface.h>
 // Wayland
 #include <wayland-client-protocol.h>
@@ -35,8 +19,7 @@ namespace KWayland
 {
 namespace Client
 {
-
-class Surface::Private
+class Q_DECL_HIDDEN Surface::Private
 {
 public:
     Private(Surface *q);
@@ -51,7 +34,8 @@ public:
 
     void setup(wl_surface *s);
 
-    static QList<Surface*> s_surfaces;
+    static QList<Surface *> s_surfaces;
+
 private:
     void handleFrameCallback();
     static void frameCallback(void *data, wl_callback *callback, uint32_t time);
@@ -63,7 +47,7 @@ private:
     static const wl_surface_listener s_surfaceListener;
 };
 
-QList<Surface*> Surface::Private::s_surfaces = QList<Surface*>();
+QList<Surface *> Surface::Private::s_surfaces = QList<Surface *>();
 
 Surface::Private::Private(Surface *q)
     : q(q)
@@ -88,15 +72,12 @@ Surface *Surface::fromWindow(QWindow *window)
     if (!window) {
         return nullptr;
     }
-    if (!QGuiApplication::platformName().contains(QStringLiteral("wayland"), Qt::CaseInsensitive)) {
-        return nullptr;
-    }
     QPlatformNativeInterface *native = qApp->platformNativeInterface();
     if (!native) {
         return nullptr;
     }
     window->create();
-    wl_surface *s = reinterpret_cast<wl_surface*>(native->nativeResourceForWindow(QByteArrayLiteral("surface"), window));
+    wl_surface *s = reinterpret_cast<wl_surface *>(native->nativeResourceForWindow(QByteArrayLiteral("surface"), window));
     if (!s) {
         return nullptr;
     }
@@ -151,7 +132,7 @@ void Surface::Private::setup(wl_surface *s)
 void Surface::Private::frameCallback(void *data, wl_callback *callback, uint32_t time)
 {
     Q_UNUSED(time)
-    auto s = reinterpret_cast<Surface::Private*>(data);
+    auto s = reinterpret_cast<Surface::Private *>(data);
     if (callback) {
         wl_callback_destroy(callback);
     }
@@ -161,42 +142,44 @@ void Surface::Private::frameCallback(void *data, wl_callback *callback, uint32_t
 void Surface::Private::handleFrameCallback()
 {
     frameCallbackInstalled = false;
-    emit q->frameRendered();
+    Q_EMIT q->frameRendered();
 }
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-const struct wl_callback_listener Surface::Private::s_listener = {
-        frameCallback
-};
+#ifndef K_DOXYGEN
+const struct wl_callback_listener Surface::Private::s_listener = {frameCallback};
 
-const struct wl_surface_listener Surface::Private::s_surfaceListener = {
-        enterCallback,
-        leaveCallback
-};
+const struct wl_surface_listener Surface::Private::s_surfaceListener = {enterCallback, leaveCallback};
 #endif
 
 void Surface::Private::enterCallback(void *data, wl_surface *surface, wl_output *output)
 {
     Q_UNUSED(surface);
-    auto s = reinterpret_cast<Surface::Private*>(data);
+    auto s = reinterpret_cast<Surface::Private *>(data);
     Output *o = Output::get(output);
     if (!o) {
         return;
     }
     s->outputs << o;
-    emit s->q->outputEntered(o);
+    QObject::connect(o, &Output::removed, s->q, [s, o]() {
+        if (!s->outputs.contains(o)) {
+            return;
+        }
+        s->outputs.removeOne(o);
+        s->q->outputLeft(o);
+    });
+    Q_EMIT s->q->outputEntered(o);
 }
 
 void Surface::Private::leaveCallback(void *data, wl_surface *surface, wl_output *output)
 {
     Q_UNUSED(surface);
-    auto s = reinterpret_cast<Surface::Private*>(data);
+    auto s = reinterpret_cast<Surface::Private *>(data);
     Output *o = Output::get(output);
     if (!o) {
         return;
     }
     s->outputs.removeOne(o);
-    emit s->q->outputLeft(o);
+    Q_EMIT s->q->outputLeft(o);
 }
 
 void Surface::Private::setupFrameCallback()
@@ -224,8 +207,8 @@ void Surface::commit(Surface::CommitFlag flag)
 
 void Surface::damage(const QRegion &region)
 {
-    for (const QRect &r : region.rects()) {
-        damage(r);
+    for (const QRect &rect : region) {
+        damage(rect);
     }
 }
 
@@ -235,6 +218,19 @@ void Surface::damage(const QRect &rect)
     wl_surface_damage(d->surface, rect.x(), rect.y(), rect.width(), rect.height());
 }
 
+void Surface::damageBuffer(const QRegion &region)
+{
+    for (const QRect &r : region) {
+        damageBuffer(r);
+    }
+}
+
+void Surface::damageBuffer(const QRect &rect)
+{
+    Q_ASSERT(isValid());
+    wl_surface_damage_buffer(d->surface, rect.x(), rect.y(), rect.width(), rect.height());
+}
+
 void Surface::attachBuffer(wl_buffer *buffer, const QPoint &offset)
 {
     Q_ASSERT(isValid());
@@ -277,23 +273,21 @@ void Surface::setSize(const QSize &size)
         return;
     }
     d->size = size;
-    emit sizeChanged(d->size);
+    Q_EMIT sizeChanged(d->size);
 }
 
 Surface *Surface::get(wl_surface *native)
 {
-    auto it = std::find_if(Private::s_surfaces.constBegin(), Private::s_surfaces.constEnd(),
-        [native](Surface *s) {
-            return s->d->surface == native;
-        }
-    );
+    auto it = std::find_if(Private::s_surfaces.constBegin(), Private::s_surfaces.constEnd(), [native](Surface *s) {
+        return s->d->surface == native;
+    });
     if (it != Private::s_surfaces.constEnd()) {
         return *(it);
     }
     return nullptr;
 }
 
-const QList< Surface* > &Surface::all()
+const QList<Surface *> &Surface::all()
 {
     return Private::s_surfaces;
 }
@@ -308,12 +302,12 @@ QSize Surface::size() const
     return d->size;
 }
 
-Surface::operator wl_surface*()
+Surface::operator wl_surface *()
 {
     return d->surface;
 }
 
-Surface::operator wl_surface*() const
+Surface::operator wl_surface *() const
 {
     return d->surface;
 }
@@ -321,7 +315,7 @@ Surface::operator wl_surface*() const
 quint32 Surface::id() const
 {
     wl_surface *s = *this;
-    return wl_proxy_get_id(reinterpret_cast<wl_proxy*>(s));
+    return wl_proxy_get_id(reinterpret_cast<wl_proxy *>(s));
 }
 
 qint32 Surface::scale() const
