@@ -1,27 +1,13 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SERVER_SURFACE_INTERFACE_H
 #define WAYLAND_SERVER_SURFACE_INTERFACE_H
 
-#include "resource.h"
 #include "output_interface.h"
+#include "resource.h"
 
 #include <QObject>
 #include <QPointer>
@@ -99,12 +85,14 @@ public:
     QRegion damage() const;
     QRegion opaque() const;
     QRegion input() const;
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 5)
     /**
      * Use Surface::inputIsInfinite instead.
-     * @deprecated
-     * @see inputIsInfinite
+     * @deprecated Since 5.5, use inputIsInfinite
      */
+    KWAYLANDSERVER_DEPRECATED_VERSION(5, 5, "Use SurfaceInterface::inputIsInfinite()")
     bool inputIsInfitine() const;
+#endif
     /**
      * Replaces Surface::inputIsInfitine instead.
      * @since 5.5
@@ -124,6 +112,14 @@ public:
      * @since 5.3
      **/
     QSize size() const;
+    /**
+     * Returns the rectangle that bounds this surface and all of its sub-surfaces.
+     *
+     * QPoint(0, 0) corresponds to the upper left corner of this surface.
+     *
+     * @since 5.69
+     */
+    QRect boundingRect() const;
 
     /**
      * @returns The SubSurface for this Surface in case there is one.
@@ -289,7 +285,7 @@ public:
      * is none set.
      * @since 5.56
      **/
-    SurfaceInterface* dataProxy() const;
+    SurfaceInterface *dataProxy() const;
 
 Q_SIGNALS:
     /**
@@ -300,9 +296,9 @@ Q_SIGNALS:
      * @see buffer
      * @see damage
      **/
-    void damaged(const QRegion&);
-    void opaqueChanged(const QRegion&);
-    void inputChanged(const QRegion&);
+    void damaged(const QRegion &);
+    void opaqueChanged(const QRegion &);
+    void inputChanged(const QRegion &);
     void scaleChanged(qint32);
     void transformChanged(KWayland::Server::OutputInterface::Transform);
     /**
@@ -334,6 +330,16 @@ Q_SIGNALS:
      * @since 5.22
      **/
     void subSurfaceTreeChanged();
+    /**
+     * Emitted whenever a new child sub-surface @p subSurface is added.
+     * @since 5.70
+     */
+    void childSubSurfaceAdded(SubSurfaceInterface *subSurface);
+    /**
+     * Emitted whenver the child sub-surface @p subSurface is removed.
+     * @since 5.70
+     */
+    void childSubSurfaceRemoved(SubSurfaceInterface *subSurface);
 
     /**
      * Emitted whenever a pointer constraint get (un)installed on this SurfaceInterface.
@@ -372,6 +378,7 @@ private:
     friend class ContrastManagerInterface;
     friend class IdleInhibitManagerUnstableV1Interface;
     friend class PointerConstraintsUnstableV1Interface;
+    friend class SurfaceRole;
     explicit SurfaceInterface(CompositorInterface *parent, wl_resource *parentResource);
 
     class Private;
@@ -381,6 +388,6 @@ private:
 }
 }
 
-Q_DECLARE_METATYPE(KWayland::Server::SurfaceInterface*)
+Q_DECLARE_METATYPE(KWayland::Server::SurfaceInterface *)
 
 #endif
